==> img0ch-2.1.10.zip: img0ch/_template/zeromin2/cgroup_create.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/cap_right_menu.cs" ?>

<div id="main">

<form id="cgroupCreateContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=cgroup&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">キャップグループ管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=cgroup&amp;method=create&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">キャップグループ作成</a>
</div>

<h1>キャップグループ作成</h1>

<?cs if:Code0 ?><div class="" id="notify"></div><?cs /if ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>名前が設定されていません</p></div><?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/metadata.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/validate.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
<!--
jQuery(function(){
jQuery("form#cgroupCreateContainerForm").validate({
    "rules": {
        "name": { "required": true }
    },
    "messages": {
        "name": { "required": "名前欄を入力してください" }
    },
    "showErrors": Zeromin2.getFormErrorHandler("以下の入力エラーがあります")
});
});
//-->
</script>

<p>
<label for="name" title="name">名前</label>
<input type="text" id="name" name="name" value="" />
</p>

<p>
 <label for="bbs" title="bbs">所属する掲示板<br />
 <input type="radio" name="all" value="1" />全ての掲示板で有効にする<br />
 <input type="radio" name="all" value="0" checked="checked" />以下の掲示板で有効にする<br />
 <select id="bbs" name="bbs" title="bbs" multiple="multiple">
  <?cs each:item = BBSList ?><option value="<?cs var:html_escape(item.id) ?>"><?cs var:item.name ?></option>
  <?cs /each ?>
 </select>
</p>

<div class="noListStyle">
 <span onclick="Zeromin2.autoCheckbox( this, 'privilege' )">権限設定</span>
 <ul>
  <li><input id="privilege_1" type="checkbox" name="privilege" value="1" />&nbsp;<label for="privilege_1">投稿時の量にかかわる制限の解除</label></li>
  <li><input id="privilege_2" type="checkbox" name="privilege" value="2" />&nbsp;<label for="privilege_2">PROXY経由での書き込みの許可</label></li>
  <li><input id="privilege_4" type="checkbox" name="privilege" value="4" />&nbsp;<label for="privilege_4">無制限のスレッド作成許可</label></li>
  <li><input id="privilege_8" type="checkbox" name="privilege" value="8" />&nbsp;<label for="privilege_8">SAMBA24制限の解除</label></li>
  <li><input id="privilege_16" type="checkbox" name="privilege" value="16" />&nbsp;<label for="privilege_16">連続投稿制限の解除</label></li>
  <li><input id="privilege_32" type="checkbox" name="privilege" value="32" />&nbsp;<label for="privilege_32">二重投稿制限の解除</label></li>
  <li><input id="privilege_64" type="checkbox" name="privilege" value="64" />&nbsp;<label for="privilege_64">キャップのみの掲示板に対するスレッド作成の許可</label></li>
  <li><input id="privilege_128" type="checkbox" name="privilege" value="128" />&nbsp;<label for="privilege_128">キャップのみの掲示板に対する投稿の許可</label></li>
  <li><input id="privilege_256" type="checkbox" name="privilege" value="256" />&nbsp;<label for="privilege_256">IDの非表示(ID:???)</label></li>
  <li><input id="privilege_512" type="checkbox" name="privilege" value="512" />&nbsp;<label for="privilege_512">名前の後の★の付加</label></li>
 </ul>
</div>

<div class="formFooter">
<input type="hidden" id="_<?cs var:html_escape(SessionName) ?>" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" id="_token" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" id="_class" name="class" value="cgroup" />
<input type="hidden" id="_method" name="method" value="save" />
<input type="hidden" id="_OK" name="OK" value="load" />
<input type="hidden" id="_NG" name="NG" value="create" />
<input type="submit" value="作成" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.1.7.zip: img0ch/_template/zeromin2/cgroup_create.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/cap_right_menu.cs" ?>

<div id="main">

<form id="cgroupCreateContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=cgroup&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">キャップグループ管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=cgroup&amp;method=create&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">キャップグループ作成</a>
</div>

<h1>キャップグループ作成</h1>

<?cs if:Code0 ?><div class="" id="notify"></div><?cs /if ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>名前が設定されていません</p></div><?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/metadata.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/validate.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
<!--
jQuery(function(){
jQuery("#cgroupCreateContainerForm").validate({
    "rules": {
        "name": { "required": true }
    },
    "messages": {
        "name": { "required": "名前欄を入力してください" }
    },
    "showErrors": Zeromin2.getFormErrorHandler("以下の入力エラーがあります")
});
});
//-->
</script>

<p>
<label for="name" title="name">名前</label>
<input type="text" id="name" name="name" value="" />
</p>

<p>
 <label for="bbs" title="bbs">所属する掲示板<br />
 <input type="radio" name="all" value="1" />全ての掲示板で有効にする<br />
 <input type="radio" name="all" value="0" checked="checked" />以下の掲示板で有効にする<br />
 <select id="bbs" name="bbs" title="bbs" multiple="multiple">
  <?cs each:item = BBSList ?><option value="<?cs var:html_escape(item.id) ?>"><?cs var:item.name ?></option>
  <?cs /each ?>
 </select>
</p>

<div class="noListStyle">
 <span onclick="Zeromin2.autoCheckbox( this, 'privilege' )">権限設定</span>
 <ul>
  <li><input id="privilege_1" type="checkbox" name="privilege" value="1" />&nbsp;<label for="privilege_1">投稿時の量にかかわる制限の解除</label></li>
  <li><input id="privilege_2" type="checkbox" name="privilege" value="2" />&nbsp;<label for="privilege_2">PROXY経由での書き込みの許可</label></li>
  <li><input id="privilege_4" type="checkbox" name="privilege" value="4" />&nbsp;<label for="privilege_4">無制限のスレッド作成許可</label></li>
  <li><input id="privilege_8" type="checkbox" name="privilege" value="8" />&nbsp;<label for="privilege_8">SAMBA24制限の解除</label></li>
  <li><input id="privilege_16" type="checkbox" name="privilege" value="16" />&nbsp;<label for="privilege_16">連続投稿制限の解除</label></li>
  <li><input id="privilege_32" type="checkbox" name="privilege" value="32" />&nbsp;<label for="privilege_32">二重投稿制限の解除</label></li>
  <li><input id="privilege_64" type="checkbox" name="privilege" value="64" />&nbsp;<label for="privilege_64">キャップのみの掲示板に対するスレッド作成の許可</label></li>
  <li><input id="privilege_128" type="checkbox" name="privilege" value="128" />&nbsp;<label for="privilege_128">キャップのみの掲示板に対する投稿の許可</label></li>
  <li><input id="privilege_256" type="checkbox" name="privilege" value="256" />&nbsp;<label for="privilege_256">IDの非表示(ID:???)</label></li>
  <li><input id="privilege_512" type="checkbox" name="privilege" value="512" />&nbsp;<label for="privilege_512">名前の後の★の付加</label></li>
 </ul>
</div>

<div class="formFooter">
<input type="hidden" id="_<?cs var:html_escape(SessionName) ?>" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" id="_token" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" id="_class" name="class" value="cgroup" />
<input type="hidden" id="_method" name="method" value="save" />
<input type="hidden" id="_OK" name="OK" value="load" />
<input type="hidden" id="_NG" name="NG" value="create" />
<input type="submit" value="作成" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
